@@ -251,12 +251,9 @@ typedef struct nv_event_s
     void  *file;  /* per file-descriptor data pointer */
     NvU32 handle;
     NvU32 fd;
-    NvU32 flags;
     struct nv_event_s *next;
 } nv_event_t;
 
-#define NV_EVENT_FLAGS_DATA_VALID    (1<<0)
-
 typedef struct nv_kern_mapping_s
 {
     void  *addr;
@@ -528,11 +525,13 @@ void   NV_API_CALL  nv_acpi_methods_uninit       (void);
 RM_STATUS  NV_API_CALL  nv_acpi_method           (NvU32, NvU32, NvU32, void *, NvU16, NvU32 *, void *, NvU16 *);
 RM_STATUS  NV_API_CALL  nv_acpi_dsm_method       (nv_state_t *, NvU8 *, NvU32, NvU32, void *, NvU16, NvU32 *, void *, NvU16 *);
 RM_STATUS  NV_API_CALL  nv_acpi_ddc_method       (nv_state_t *, void *, NvU32 *);
-void*  NV_API_CALL  nv_get_smu_state             (void);
+RM_STATUS  NV_API_CALL  nv_acpi_dod_method       (nv_state_t *, NvU32 *, NvU32 *);
+void*      NV_API_CALL  nv_get_smu_state         (void);
 RM_STATUS  NV_API_CALL  nv_lock_user_pages       (nv_state_t *, void *, NvU64, NvU64 *, void **);
 RM_STATUS  NV_API_CALL  nv_unlock_user_pages     (nv_state_t *, NvU64, NvU64 *, void *);
 RM_STATUS  NV_API_CALL  nv_acpi_rom_method       (nv_state_t *, NvU32 *, NvU32 *);
 RM_STATUS  NV_API_CALL  nv_log_error             (nv_state_t *, NvU32, const char *, va_list);
+
 #if defined(NV_MOBILE_DGPU)
 RM_STATUS  NV_API_CALL  nv_nvmap_create_client   (void);
 void       NV_API_CALL  nv_nvmap_destroy_client  (void);
