@@ -734,18 +734,23 @@ void NV_API_CALL nv_post_event(
     struct nvidia_filep *filep = event->file;
     struct nvidia_event *et;
 
-    et = malloc(sizeof(nvidia_event_t), M_NVIDIA, M_NOWAIT);
-    if (et == NULL)
-        return;
-
-    et->event = *event;
-    et->event.hObject = hObject;
-    et->event.index = index;
-    if (data_valid)
-        et->event.flags |= NV_EVENT_FLAGS_DATA_VALID;
-
     mtx_lock(&filep->event_mtx);
-    STAILQ_INSERT_TAIL(&filep->event_queue, et, queue);
+
+    if (data_valid) {
+        et = malloc(sizeof(nvidia_event_t), M_NVIDIA, M_NOWAIT);
+        if (et == NULL) {
+            mtx_unlock(&filep->event_mtx);
+            return;
+        }
+
+        et->event = *event;
+        et->event.hObject = hObject;
+        et->event.index = index;
+
+        STAILQ_INSERT_TAIL(&filep->event_queue, et, queue);
+    }
+
+    filep->event_pending = TRUE;
     mtx_unlock(&filep->event_mtx);
 
     selwakeup(&filep->event_rsel);
@@ -762,22 +767,24 @@ NvS32 NV_API_CALL nv_get_event(
     struct nvidia_event *et;
 
     mtx_lock(&filep->event_mtx);
+
     et = STAILQ_FIRST(&filep->event_queue);
-
-    if (et != NULL) {
-        *event = et->event;
-
-        STAILQ_REMOVE(&filep->event_queue, et, nvidia_event, queue);
-        *pending = !STAILQ_EMPTY(&filep->event_queue);
-
+    if (et == NULL) {
         mtx_unlock(&filep->event_mtx);
-        free(et, M_NVIDIA);
-
-        return RM_OK;
+        return RM_ERROR;
     }
 
+    *event = et->event;
+
+    STAILQ_REMOVE(&filep->event_queue, et, nvidia_event, queue);
+
+    *pending = !STAILQ_EMPTY(&filep->event_queue);
+
     mtx_unlock(&filep->event_mtx);
-    return RM_ERROR;
+
+    free(et, M_NVIDIA);
+
+    return RM_OK;
 }
 
 void* NV_API_CALL nv_alloc_kernel_mapping(
@@ -1491,6 +1498,15 @@ RM_STATUS NV_API_CALL nv_acpi_ddc_method(
     return RM_ERR_NOT_SUPPORTED;
 }
 
+RM_STATUS NV_API_CALL nv_acpi_dod_method(
+    nv_state_t *nv,
+    NvU32      *pOutData,
+    NvU32      *pSize
+)
+{
+    return RM_ERR_NOT_SUPPORTED;
+}
+
 RM_STATUS NV_API_CALL nv_acpi_rom_method(
     nv_state_t *nv,
     NvU32 *pInData,
