@@ -141,6 +141,10 @@ typedef NvU8 NvTristate;
 #define NvU40_HI32(n)     ((NvU32)((((NvU64)(n)) >>  8) & 0xffffffff))
 #define NvU40_HI24of32(n) ((NvU32)(  (NvU64)(n)         & 0xffffff00))
 
+/* Macros to get the MSB and LSB of a 32 bit unsigned number */
+#define NvU32_HI16(n)     ((NvU16)((((NvU32)(n)) >> 16) & 0xffff))
+#define NvU32_LO16(n)     ((NvU16)(( (NvU32)(n))        & 0xffff))
+
  /***************************************************************************\
 |*                                                                           *|
 |*  64 bit type definitions for use in interface structures.                 *|
@@ -379,15 +383,14 @@ typedef NvS32                                                      NvSFXP20_12;
 typedef NvS32                                                       NvSFXP24_8;
 typedef NvS32                                                       NvSFXP27_5;
 typedef NvS32                                                       NvSFXP29_3;
-typedef NvS32                                                       NvSFXP31_1;
 
 typedef NvU16                                                       NvUFXP4_12;
+typedef NvU16                                                        NvUFXP8_8;
 typedef NvU32                                                       NvUFXP8_24;
 typedef NvU32                                                       NvUFXP9_23;
 typedef NvU32                                                      NvUFXP16_16;
 typedef NvU32                                                      NvUFXP20_12;
 typedef NvU32                                                       NvUFXP24_8;
-typedef NvU32                                                       NvUFXP25_7;
 
 /*!
  * Utility macros used in converting between signed integers and fixed-point
