@@ -26,6 +26,11 @@ typedef NvU32 RM_STATUS;
 #define RM_OK                           0x00000000
 #define RM_ERROR                        0xFFFFFFFF
 
+/*
+  This bit is reserved, no RM_STATUS should ever have it set
+  NVOS_STATUS_IN_RM_STATUS              0x80000000
+*/
+
 #define RM_ERR_CANT_CREATE_CLASS_OBJS   0x00000001
 #define RM_ERR_DMA_IN_USE               0x00000002
 #define RM_ERR_DMA_MEM_NOT_LOCKED       0x00000003
